@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2016 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -57,7 +57,7 @@ void pws_os::GetRandomSeed(void *p, unsigned &slen)
    * Return a cryptographically strong seed
    * from /dev/random, if possible.
    *
-   * When called with p == NULL, return nuber of bytes currently
+   * When called with p == NULL, return number of bytes currently
    * in entropy pool.
    * To minimize TOCTTOU, we also read the data at this time,
    * and deliver it when called with non-NULL p.
@@ -92,9 +92,13 @@ void pws_os::GetRandomSeed(void *p, unsigned &slen)
     // here if we had any trouble getting data from /dev/random
     get_failsafe_rnd(data, slen);
   } else { // called with non-NULL p, just return our hard-earned entropy
-    assert(data != NULL); // MUST call with p == NULL first!
-    memcpy(p, data, slen);
-    delete[] data;
-    data = NULL;
+    if (data) {
+      memcpy(p, data, slen);
+      delete[] data;
+      data = NULL;
+    }
+    else {
+      assert(false); // MUST call with p == NULL first!
+    }
   }
 }    
