@@ -18,7 +18,6 @@
 
 #include "PWTreeCtrl.h"
 #include "PWListCtrl.h"
-#include "RUEList.h"
 #include "CoolMenu.h"
 #include "MenuTipper.h"
 #include "LVHdrCtrl.h"
@@ -39,6 +38,7 @@
 #include "core/PwsPlatform.h"
 #include "core/PWSFilters.h"
 #include "core/Command.h"
+#include "core/RUEList.h"
 
 #include "os/run.h"
 #include "os/UUID.h"
@@ -317,7 +317,8 @@ public:
   bool ClearClipboardData() {return m_clipboard.ClearData();}
   bool SetClipboardData(const StringX &data)
   {return m_clipboard.SetData(data.c_str());}
-  void AddDDEntries(CDDObList &in_oblist, const StringX &DropGroup);
+  void AddDDEntries(CDDObList &in_oblist, const StringX &DropGroup,
+    const std::vector<StringX> &vsxEmptyGroups);
   StringX GetUniqueTitle(const StringX &group, const StringX &title,
                          const StringX &user, const int IDS_MESSAGE) const
   {return m_core.GetUniqueTitle(group, title, user, IDS_MESSAGE);}
@@ -632,16 +633,9 @@ public:
   bool EditShortcut(CItemData *pci, PWScore *pcore = NULL);
   void SetFindToolBar(bool bShow);
   void ApplyFilters();
-
+  
   void GetMonitorRect(HWND hwnd, RECT *prc, BOOL fWork);
   void ClipRectToMonitor(HWND hwnd, RECT *prc, BOOL fWork);
-  bool PassesFiltering(const CItemData &ci, const st_filters &filters);
-  bool PassesPWHFiltering(const CItemData *pci,
-                          const st_filters &filters) const;
-  bool PassesPWPFiltering(const CItemData *pci,
-                          const st_filters &filters) const;
-  bool PassesAttFiltering(const CItemData *pci,
-                          const st_filters &filters) const;
 
   void SaveGUIStatus();
   void RestoreGUIStatus();
@@ -935,26 +929,16 @@ private:
   CInfoDisplay *m_pNotesDisplay;
 
   // Filters
-  bool m_bFilterActive, m_bFilterForStatus, m_bFilterForType, m_bUnsavedDisplayed, m_bExpireDisplayed;
+  bool m_bFilterActive, m_bUnsavedDisplayed, m_bExpireDisplayed;
   // Current filter
-  st_filters m_currentfilter;
-  // Special Show Unsaved Changes filter
-  st_filters m_showunsavedfilter;
-  // Special Show Expired/expiring passwords filter
-  st_filters m_showexpirefilter;
-
-  // Sorted Groups
-  vfiltergroups m_vMflgroups;
-  vfiltergroups m_vHflgroups;
-  vfiltergroups m_vPflgroups;
-  vfiltergroups m_vAflgroups;
+  st_filters &CurrentFilter() {return m_FilterManager.m_currentfilter;}
 
   // Global Filters
+  PWSFilterManager m_FilterManager;
   PWSFilters m_MapFilters;
   FilterPool m_currentfilterpool;
   CString m_selectedfiltername;
 
-  void CreateGroups();
   int m_bNumPassedFiltering;
 
   PWSRun m_runner; // for executing external programs
@@ -1009,7 +993,7 @@ private:
   CompareData m_list_Conflicts;
   CompareData m_list_Identical;
 
-  // Flag to tell user there are some expird entries
+  // Flag to tell user there are some expired entries
   bool m_bTellUserExpired;
 
   // Prevent rename of entries in Tree mode by clicking on entry
