@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2016 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -33,6 +33,7 @@
 #include "HKModifiers.h"
 #include "YubiCfgDlg.h"
 
+#include "core/core.h"
 #include "core/pwsprefs.h"
 #include "core/PWSdirs.h"
 #include "core/PWSAuxParse.h"
@@ -118,7 +119,7 @@ int DboxMain::BackupSafe()
       return PWScore::USER_CANCEL;
   }
 
-  rc = m_core.WriteFile(tempname, false);
+  rc = m_core.WriteFile(tempname, m_core.GetReadFileVersion(), false);
   if (rc == PWScore::CANT_OPEN_FILE) {
     CGeneralMsgBox gmb;
     cs_temp.Format(IDS_CANTOPENWRITING, tempname);
@@ -298,30 +299,30 @@ void DboxMain::OnOptions()
     iPWSHotKeyValue = pOptionsPS->GetHotKeyValue();
 
     // Update status bar
-    UINT uiMessage(IDS_STATCOMPANY);
+    UINT uiMessage(IDSC_STATCOMPANY);
     switch (pOptionsPS->GetDCA()) {
       case PWSprefs::DoubleClickAutoType:
-        uiMessage = IDS_STATAUTOTYPE; break;
+        uiMessage = IDSC_STATAUTOTYPE; break;
       case PWSprefs::DoubleClickBrowse:
-        uiMessage = IDS_STATBROWSE; break;
+        uiMessage = IDSC_STATBROWSE; break;
       case PWSprefs::DoubleClickCopyNotes:
-        uiMessage = IDS_STATCOPYNOTES; break;
+        uiMessage = IDSC_STATCOPYNOTES; break;
       case PWSprefs::DoubleClickCopyPassword:
-        uiMessage = IDS_STATCOPYPASSWORD; break;
+        uiMessage = IDSC_STATCOPYPASSWORD; break;
       case PWSprefs::DoubleClickCopyUsername:
-        uiMessage = IDS_STATCOPYUSERNAME; break;
+        uiMessage = IDSC_STATCOPYUSERNAME; break;
       case PWSprefs::DoubleClickViewEdit:
-        uiMessage = IDS_STATVIEWEDIT; break;
+        uiMessage = IDSC_STATVIEWEDIT; break;
       case PWSprefs::DoubleClickCopyPasswordMinimize:
-        uiMessage = IDS_STATCOPYPASSWORDMIN; break;
+        uiMessage = IDSC_STATCOPYPASSWORDMIN; break;
       case PWSprefs::DoubleClickBrowsePlus:
-        uiMessage = IDS_STATBROWSEPLUS; break;
+        uiMessage = IDSC_STATBROWSEPLUS; break;
       case PWSprefs::DoubleClickRun:
-        uiMessage = IDS_STATRUN; break;
+        uiMessage = IDSC_STATRUN; break;
       case PWSprefs::DoubleClickSendEmail:
-        uiMessage = IDS_STATSENDEMAIL; break;
+        uiMessage = IDSC_STATSENDEMAIL; break;
       default:
-        uiMessage = IDS_STATCOMPANY;
+        uiMessage = IDSC_STATCOMPANY;
     }
     statustext[CPWStatusBar::SB_DBLCLICK] = uiMessage;
     m_statusBar.SetIndicators(statustext, CPWStatusBar::SB_TOTAL);
@@ -478,7 +479,7 @@ void DboxMain::OnOptions()
 
     if (m_core.GetReadFileVersion() == PWSfile::VCURRENT) {
       if (sxOldDBPrefsString != sxNewDBPrefsString) {
-        // Determine whether Tree needs redisplayng due to change
+        // Determine whether Tree needs redisplaying due to change
         // in what is shown (e.g. usernames/passwords)
         bool bUserDisplayChanged = pOptionsPS->UserDisplayChanged();
         // Note: passwords are only shown in the Tree if usernames are also shown
@@ -644,8 +645,10 @@ void DboxMain::OnGeneratePassword()
 
 void DboxMain::OnYubikey()
 {
+#ifndef NO_YUBI
   CYubiCfgDlg dlg(this, m_core);
   dlg.DoModal();
+#endif /* NO_YUBI */
 }
 
 void DboxMain::OnManagePasswordPolicies()
@@ -695,15 +698,15 @@ void DboxMain::OnManagePasswordPolicies()
 
       // Set up Command to update string in database
       if (m_core.GetReadFileVersion() == PWSfile::VCURRENT) {
-          Command *pcmd1 = DBPrefsCommand::Create(&m_core, sxNewDBPrefsString);
-          pmulticmds->Add(pcmd1);
+        Command *pcmd_undo = DBPrefsCommand::Create(&m_core, sxNewDBPrefsString);
+        pmulticmds->Add(pcmd_undo);
       }
     }
 
     // Now update named preferences
-    Command *pcmd2 = DBPolicyNamesCommand::Create(&m_core, MapPSWDPLC,
+    Command *pcmd = DBPolicyNamesCommand::Create(&m_core, MapPSWDPLC,
                              DBPolicyNamesCommand::NP_REPLACEALL);
-    pmulticmds->Add(pcmd2);
+    pmulticmds->Add(pcmd);
     Execute(pmulticmds);
 
     // Update Minidump user streams
