@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
+ * Copyright (c) 2003-2016 Rony Shapiro <ronys@pwsafe.org>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -142,7 +142,7 @@ bool MenuItemData::IsDirty() const {
 }
 
 /*
- * The only realiable way to change the accelerator, atleast for 2.8.11, is to
+ * The only reliable way to change the accelerator, at least for 2.8.11, is to
  * set a new and complete label, with full mnemonics + accelerator.   Don't
  * use wxMenuItem::SetAccel(), or do * SetItemLabel(SomeManipulation(GetItemLabelText()))).
  * You will end up with underscores in place where the '&' mnemonic is, and they would multiply
@@ -351,7 +351,7 @@ PWSMenuShortcuts* PWSMenuShortcuts::CreateShortcutsManager(wxMenuBar* menubar)
 
 PWSMenuShortcuts* PWSMenuShortcuts::GetShortcutsManager()
 {
-  wxASSERT_MSG(g_pShortcutsManager, wxT("Shortcuts manager being used before creation or after destruction"));;
+  wxASSERT_MSG(g_pShortcutsManager, wxT("Shortcuts manager being used before creation or after destruction"));
   return g_pShortcutsManager;
 }
 
@@ -441,8 +441,8 @@ void PWSMenuShortcuts::ReadApplyUserShortcuts()
       itr->ApplyEffectiveShortcut();
     }
     else {
-      wxLogDebug(wxT("Could not find menu item id=[%d], for saved shortcut {key=[%d], mods=[%d]}"),
-                                usrItr->id, usrItr->siVirtKey, usrItr->cModifier);
+      pws_os::Trace(L"Could not find menu item id=[%d], for saved shortcut {key=[%d], mods=[%d]}",
+                    usrItr->id, usrItr->siVirtKey, usrItr->cModifier);
     }
   }
 }
@@ -548,7 +548,7 @@ void PWSMenuShortcuts::SetShorcutsGridEventHandlers(wxGrid* grid, wxButton* rese
   m_shortcutGridStatus.resize(m_midata.size());
   std::transform(m_midata.begin(), m_midata.end(), m_shortcutGridStatus.begin(), std::mem_fun_ref(&MenuItemData::GetStatus));
 
-  grid->Connect(wxEVT_GRID_CELL_CHANGE, wxGridEventHandler(PWSMenuShortcuts::OnShortcutChange), NULL, this);
+  grid->Connect(wxEVT_GRID_CELL_CHANGED, wxGridEventHandler(PWSMenuShortcuts::OnShortcutChange), NULL, this);
   grid->Connect(wxEVT_GRID_CELL_RIGHT_CLICK, wxGridEventHandler(PWSMenuShortcuts::OnShortcutRightClick), NULL, this);
   //let's not directly connect to the grid for key events.  We'll only handle what bubbles up to us
   grid->GetGridWindow()->Connect(grid->GetGridWindow()->GetId(), wxEVT_KEY_DOWN, wxKeyEventHandler(PWSMenuShortcuts::OnShortcutKey), NULL, this);
@@ -599,7 +599,7 @@ void PWSMenuShortcuts::OnShortcutKey(wxKeyEvent& evt)
                 && col == COL_SHORTCUT_KEY) {
     wxAcceleratorEntry accel(ModifiersToAccelFlags(evt.GetModifiers()), evt.GetKeyCode(), 0);
     wxCHECK_RET(IsNotNull(accel), wxT("Could not create accelerator from wxKeyEvent"));
-    const int row = grid->GetCursorRow();
+    const int row = grid->GetGridCursorRow();
     grid->SetCellValue(row, col, accel.ToString());
     grid->SetCellTextColour(row, col, grid->GetDefaultCellTextColour());
     m_shortcutGridStatus[row].setchanged();
